pub type LocalStr = FlexStr<'static, str, Rc<str>>;Available on crate feature
str only.Expand description
Local str type (NOTE: This can’t be shared between threads)
Aliased Type
pub enum LocalStr {
Borrowed(&'static str),
Inlined(InlineFlexStr<str>),
RefCounted(Rc<str>),
Boxed(Box<str>),
}Variants
Borrowed(&'static str)
Borrowed string - borrowed strings are imported as &S
Inlined(InlineFlexStr<str>)
Inline string - owned strings that are small enough to be stored inline
RefCounted(Rc<str>)
Reference counted string - owned strings that are too large for inline storage
Boxed(Box<str>)
Boxed string - heap allocated strings are imported as Box<S>